@@ -35,16 +35,18 @@ val find_all : string -> Ocsigen_http_frame.t -> string list
 val get_keepalive : Ocsigen_http_frame.Http_header.http_header -> bool
 val parse_cookies : string  -> string CookiesTable.t
 val parse_mime_type : string -> string option * string option
-val get_host_from_host_header : Ocsigen_http_frame.t -> 
+val get_host_from_host_header : Ocsigen_http_frame.t ->
   string option * int option
 val get_user_agent : Ocsigen_http_frame.t -> string
 val get_cookie_string : Ocsigen_http_frame.t -> string option
+val get_expect : Ocsigen_http_frame.t -> string list
 val get_if_modified_since : Ocsigen_http_frame.t -> float option
 val get_if_unmodified_since : Ocsigen_http_frame.t -> float option
 val get_if_none_match : Ocsigen_http_frame.t -> string list option
 val get_if_match : Ocsigen_http_frame.t -> string list option
 val get_content_type : Ocsigen_http_frame.t -> string option
-val parse_content_type : string option -> ((string * string) * (string * string) list) option
+val parse_content_type
+  : string option -> ((string * string) * (string * string) list) option
 val get_content_length : Ocsigen_http_frame.t -> int64 option
 val get_referer : Ocsigen_http_frame.t -> string option
 val get_referrer : Ocsigen_http_frame.t -> string option
