@@ -1,7 +1,7 @@
 (* Ocsigen
  * http://www.ocsigen.org
  * Copyright (C) 2005
- * Vincent Balat, Denis Berthod, Nataliya Guts, Jrme Vouillon
+ * Vincent Balat, Denis Berthod, Nataliya Guts, Jérôme Vouillon
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,6 @@ open Ocsigen_parseconfig
 open Ocsigen_cookies
 open Lazy
 
-
 exception Ocsigen_unsupported_media
 exception Ssl_Exception
 exception Ocsigen_upload_forbidden
@@ -79,17 +78,17 @@ let make_sockets addr port =
            corresponds to the net.ipv6.bindv6only=0 behaviour on Linux,
            but is portable and should work with
            net.ipv6.bindv6only=1 as well. *)
-        let ipv6_socket =
-          try [make_ipv6_socket Unix.inet6_addr_any port]
-          with Unix.Unix_error
-              ((Unix.EAFNOSUPPORT | Unix.EPROTONOSUPPORT),
-               _, _) -> []
-        in
-        (make_ipv4_socket Unix.inet_addr_any port)::ipv6_socket
+      let ipv6_socket =
+        try [make_ipv6_socket Unix.inet6_addr_any port]
+        with Unix.Unix_error
+            ((Unix.EAFNOSUPPORT | Unix.EPROTONOSUPPORT),
+             _, _) -> []
+      in
+      (make_ipv4_socket Unix.inet_addr_any port)::ipv6_socket
     | IPv4 addr ->
-        [make_ipv4_socket addr port]
+      [make_ipv4_socket addr port]
     | IPv6 addr ->
-        [make_ipv6_socket addr port]
+      [make_ipv6_socket addr port]
 
 let sslctx = Ocsigen_http_client.sslcontext
 
@@ -112,7 +111,8 @@ let find_field field content_disp =
 
 type to_write =
     No_File of string * Buffer.t
-  | A_File of (string * string * string * Unix.file_descr * (string * string option) option)
+  | A_File of (string * string * string * Unix.file_descr
+               * ((string * string) * (string * string) list) option)
 
 let counter = let c = ref (Random.int 1000000) in fun () -> c := !c + 1 ; !c
 
@@ -127,8 +127,6 @@ let dbg sockaddr s =
        "While talking to " ^ ip ^ ": " ^ s)
 
 
-let r_content_type = Netstring_pcre.regexp "([^ ]*)"
-
 let http_url_syntax = Hashtbl.find Neturl.common_url_syntax "http"
 
 let rec find_post_params http_frame ct filenames =
@@ -176,14 +174,7 @@ and find_post_params_multipart_form_data body_gen ctparams filenames ci =
     let content_type =
       try
         let ct = List.assoc "content-type" hs in
-        let content_type =
-          let (_, res) = Netstring_pcre.search_forward r_content_type ct 0 in
-          Netstring_pcre.matched_group res 1 ct
-        in
-        let charset = try
-          Some (find_field "charset" ct)
-        with _ -> None
-        in Some (content_type, charset)
+        Ocsigen_headers.parse_content_type (Some ct)
       with _ -> None
     in
     let cd = List.assoc "content-disposition" hs in
@@ -222,7 +213,7 @@ and find_post_params_multipart_form_data body_gen ctparams filenames ci =
     | No_File (p_name, to_buf) ->
         return
           (params := !params @ [(p_name, Buffer.contents to_buf)])
-          (*  la fin ? *)
+          (* a la fin ? *)
     | A_File (p_name,fname,oname,wh, content_type) ->
         (* Ocsigen_messages.debug "closing file"; *)
         files :=
@@ -243,11 +234,47 @@ and find_post_params_multipart_form_data body_gen ctparams filenames ci =
   Ocsigen_stream.consume body_gen >>= fun () ->
   Lwt.return (!params, !files)
 
+let wrap_stream f x frame_content =
+  Ocsigen_stream.make ~finalize:(fun outcome ->
+      match frame_content with
+      | Some stream ->
+        Ocsigen_stream.finalize stream outcome
+      | None ->
+        Lwt.return ()
+    )
+    (fun () ->
+       f x >>= fun () ->
+       match frame_content with
+       | Some stream ->
+         Ocsigen_stream.next (Ocsigen_stream.get stream)
+       | None ->
+         Ocsigen_stream.empty None
+    )
 
+let handle_100_continue slot frame =
+  { frame with
+    frame_content = Some (wrap_stream send_100_continue slot
+    frame.frame_content)
+  }
+
+let handle_expect slot frame =
+  let expect_list = Ocsigen_headers.get_expect frame in
+  let proto = Http_header.get_proto frame.frame_header in
+  List.fold_left (fun frame tok ->
+    match String.lowercase tok with
+    | "100-continue" ->
+        if proto = Http_header.HTTP11 then
+          handle_100_continue slot frame
+        else
+          frame
+    | _ ->
+      raise (Ocsigen_http_error (Ocsigen_cookies.empty_cookieset, 417))
+  ) frame expect_list
 
 (* reading the request *)
 let get_request_infos
-    meth clientproto url http_frame filenames sockaddr port receiver =
+    meth clientproto url http_frame filenames sockaddr port receiver
+    sender_slot =
 
   Lwt.catch
     (fun () ->
@@ -329,6 +356,8 @@ let get_request_infos
        let post_params0 =
          match meth with
            | Http_header.GET
+           | Http_header.DELETE
+           | Http_header.PUT
            | Http_header.HEAD -> None
            | Http_header.POST
            | Http_header.OPTIONS ->
@@ -380,7 +409,7 @@ let get_request_infos
           ri_files = files;
           ri_remote_inet_addr = client_inet_addr;
           ri_remote_ip = ipstring;
-          ri_remote_ip_parsed = lazy (fst (Ip_address.parse ipstring));
+          ri_remote_ip_parsed = lazy (Ipaddr.of_string_exn ipstring);
           ri_remote_port = port_of_sockaddr sockaddr;
 	  ri_forward_ip = [];
           ri_server_port = port;
@@ -402,7 +431,7 @@ let get_request_infos
           ri_accept_charset = accept_charset;
           ri_accept_encoding = accept_encoding;
           ri_accept_language = accept_language;
-          ri_http_frame = http_frame;
+          ri_http_frame = handle_expect sender_slot http_frame;
           ri_request_cache = Polytables.create ();
           ri_client = Ocsigen_extensions.client_of_connection receiver;
           ri_range = lazy (Ocsigen_range.get_range http_frame);
@@ -640,7 +669,9 @@ let service receiver sender_slot request meth url port sockaddr =
   if meth <> Http_header.GET &&
      meth <> Http_header.POST &&
      meth <> Http_header.HEAD &&
-     meth <> Http_header.OPTIONS
+     meth <> Http_header.OPTIONS &&
+     meth <> Http_header.DELETE &&
+     meth <> Http_header.PUT
   then begin
    (* VVV Warning: This must be done once and only once.
       Put this somewhere else to ensure that?
@@ -661,8 +692,8 @@ let service receiver sender_slot request meth url port sockaddr =
       Lwt.try_bind
         (fun () ->
            get_request_infos
-             meth clientproto url request filenames sockaddr 
-             port receiver)
+             meth clientproto url request filenames sockaddr
+             port receiver sender_slot)
         (fun ri ->
            (* *** Now we generate the page and send it *)
            (* Log *)
@@ -689,7 +720,7 @@ let service receiver sender_slot request meth url port sockaddr =
                     ri.ri_remote_ip
                     ri.ri_user_agent
                     ri.ri_url_string);
-           let send_aux = 
+           let send_aux =
              send sender_slot ~clientproto ~head
                ~sender:Ocsigen_http_com.default_sender
            in
@@ -798,22 +829,22 @@ let linger in_ch receiver =
 
 let try_bind' f g h = Lwt.try_bind f h g
 
-let add_to_receivers_waiting_for_pipeline, 
+let add_to_receivers_waiting_for_pipeline,
   remove_from_receivers_waiting_for_pipeline,
   iter_receivers_waiting_for_pipeline =
   let l = Clist.create () in
-  ((fun r -> 
+  ((fun r ->
       let node = Clist.make r in
       Clist.insert l node;
       node),
    Clist.remove,
-   (fun f -> 
+   (fun f ->
       Clist.fold_left
         (fun t v ->
           (*VVV reread this. Is yield here ok? *)
           t >>= Lwt_unix.yield >>= fun () ->
           f v)
-        (Lwt.return ()) 
+        (Lwt.return ())
         l))
 
 let handle_connection port in_ch sockaddr =
@@ -908,7 +939,7 @@ let handle_connection port in_ch sockaddr =
            | Some pos -> remove_from_receivers_waiting_for_pipeline pos
            | None -> ());
          let meth, url =
-           match 
+           match
              Http_header.get_firstline request.Ocsigen_http_frame.frame_header
            with
              | Http_header.Query a -> a
@@ -924,11 +955,11 @@ let handle_connection port in_ch sockaddr =
          if not !shutdown &&
            get_keepalive request.Ocsigen_http_frame.frame_header
          then
-           (* We put the receiver in the set of receiver waiting for 
+           (* We put the receiver in the set of receiver waiting for
               pipeline in order to be able to shutdown the connections
               if the server is shutting down.
            *)
-           handle_request 
+           handle_request
              ~receiver_pos:(add_to_receivers_waiting_for_pipeline receiver) ()
          else (* No keep-alive => no pipeline *)
             (* We wait for the query to be entirely read and for
@@ -958,7 +989,7 @@ let rec wait_connection use_ssl port socket =
         wait_connection use_ssl port socket
   in
   try_bind'
-    (fun () -> 
+    (fun () ->
        (* if too much connections,
           we wait for a signal before accepting again *)
        let max = get_max_number_of_connections () in
@@ -971,7 +1002,7 @@ let rec wait_connection use_ssl port socket =
                   (get_max_number_of_connections ())));
           wait_fewer_connected max
         end) >>= fun () ->
-       (* We do several accept(), as explained in 
+       (* We do several accept(), as explained in
          "Accept()able strategies ..." by Tim Brecht & al. *)
        Lwt_unix.accept_n socket 50)
     handle_exn
@@ -981,7 +1012,7 @@ let rec wait_connection use_ssl port socket =
         (fun () -> "received "^string_of_int number_of_accepts^" accepts"  );
       incr_connected number_of_accepts;
       if e = None then ignore (wait_connection use_ssl port socket);
-      
+
       let handle_one (s, sockaddr) =
         Ocsigen_messages.debug2
           "\n__________________NEW CONNECTION__________________________";
@@ -1010,7 +1041,7 @@ let rec wait_connection use_ssl port socket =
             | e -> Lwt.fail e)
         >>= decr_connected
       in
-      
+
       Lwt_util.iter handle_one l >>= fun () ->
       match e with
         | Some e -> handle_exn e
@@ -1082,9 +1113,9 @@ let errmsg = function
 let reload_conf s =
   try
     Ocsigen_extensions.start_initialisation ();
-    
+
     parse_server true s;
-    
+
     Ocsigen_extensions.end_initialisation ();
   with e ->
     Ocsigen_extensions.end_initialisation ();
@@ -1106,18 +1137,18 @@ let reload ?file () =
 
 
 let shutdown_server s l =
-  try 
+  try
     let timeout = match l with
       | [] -> Ocsigen_config.get_shutdown_timeout ()
       | ["notimeout"] -> None
-      | [t] -> 
+      | [t] ->
           Some (float_of_string t)
       | _ -> failwith "syntax error in command"
     in
     Ocsigen_messages.warning "Shutting down";
-    List.iter 
+    List.iter
       (fun s -> Lwt_unix.abort s Socket_closed) !sockets;
-    List.iter 
+    List.iter
       (fun s -> Lwt_unix.abort s Socket_closed) !sslsockets;
     sockets := [];
     sslsockets := [];
@@ -1333,6 +1364,11 @@ let start_server () = try
         >>= f
       in ignore (f ());
 
+      Lwt.async_exception_hook := (fun e ->
+          (* replace the default "exit 2" behaviour *)
+          Ocsigen_messages.errlog ("Uncaught Exception: "^ Printexc.to_string e)
+        );
+
       Lwt.wakeup wait_end_init_awakener ();
 
       Ocsigen_messages.warning "Ocsigen has been launched (initialisations ok)";
@@ -1365,7 +1401,7 @@ let start_server () = try
         let f =
           Unix.openfile
             p
-            [Unix.O_WRONLY; Unix.O_CREAT; Unix.O_APPEND] 0o640 in
+            [Unix.O_WRONLY; Unix.O_CREAT; Unix.O_TRUNC] 0o640 in
         ignore (Unix.write f spid 0 len);
         Unix.close f
   in
